@@ -3,6 +3,7 @@ import json
 import re
 
 import requests
+import six
 from six.moves.urllib.parse import urlencode
 
 from profitbricks import (
@@ -896,7 +897,7 @@ class ProfitBricksService(object):
 
     def create_nic(self, datacenter_id, server_id, nic):
         """
-        Creates a NIC on the specified NIC and Server.
+        Creates a NIC on the specified server.
 
         :param      datacenter_id: The unique ID of the Datacenter.
         :type       datacenter_id: ``str``
@@ -1628,13 +1629,26 @@ class ProfitBricksService(object):
         url = self.host_base + uri
         return url
 
-    def _b(self, s):
-        if isinstance(s, str):
-            return s.encode('utf-8')
-        elif isinstance(s, bytes):
-            return s
+    def _b(self, s, encoding='utf-8'):
+        """
+        Returns the given string as a string of bytes. That means in
+        Python2 as a str object, and in Python3 as a bytes object.
+        Raises a TypeError, if it cannot be converted.
+        """
+        if six.PY2:
+            # This is Python2
+            if isinstance(s, str):
+                return s
+            elif isinstance(s, unicode):
+                return s.encode(encoding)
         else:
-            raise TypeError("Invalid argument %r for b()" % (s,))
+            # And this is Python3
+            if isinstance(s, bytes):
+                return s
+            elif isinstance(s, str):
+                return s.encode(encoding)
+
+        raise TypeError("Invalid argument %r for _b()" % (s,))
 
     'Used to convert python snake case back to mixed case.'
     def _underscore_to_camelcase(self, value):
@@ -1655,7 +1669,7 @@ class ProfitBricksService(object):
         }
 
         ' Optional Properties'
-        if lan.public:
+        if lan.public is not None:
             properties['public'] = str(lan.public).lower()
 
         if len(lan.nics) > 0:
@@ -1698,7 +1712,7 @@ class ProfitBricksService(object):
         ' Optional Properties'
         if loadbalancer.ip:
             properties['ip'] = loadbalancer.ip
-        if loadbalancer.dhcp:
+        if loadbalancer.dhcp is not None:
             properties['dhcp'] = str(loadbalancer.dhcp).lower()
 
         if len(loadbalancer.balancednics) > 0:
@@ -1742,10 +1756,10 @@ class ProfitBricksService(object):
         if nic.ips:
             properties['ips'] = nic.ips
 
-        if nic.dhcp:
+        if nic.dhcp is not None:
             properties['dhcp'] = nic.dhcp
 
-        if nic.firewall_active:
+        if nic.firewall_active is not None:
             properties['firewallActive'] = nic.firewall_active
 
         if len(nic.firewall_rules) > 0:
@@ -1832,6 +1846,9 @@ class ProfitBricksService(object):
             }
             properties['bootVolume'] = boot_volume
 
+        if server.cpu_family:
+            properties['cpuFamily'] = server.cpu_family
+
         if len(server.create_volumes) > 0:
             for volume in server.create_volumes:
                 volume_items.append(self._create_volume_dict(volume))
@@ -2053,11 +2070,11 @@ class LAN(ProfitBricksService):
         """
         LAN class initializer.
 
-        :param      name: Your API username from the portal.
+        :param      name: The name of the LAN.
         :type       name: ``str``
 
-        :param      public: Your API password from the portal.
-        :type       public: ``str``
+        :param      public: Indicates if the LAN is public.
+        :type       public: ``bool``
 
         :param      nics: A list of NICs
         :type       nics: ``list``
@@ -2155,10 +2172,9 @@ class Server(ProfitBricksService):
     '''
     This is the main class for managing server resources.
     '''
-    def __init__(self, name=None, cores=None, ram=None,
-                 availability_zone=None, boot_volume_id=None,
-                 boot_cdrom=None, create_volumes=[],
-                 attach_volumes=[], nics=[]):
+    def __init__(self, name=None, cores=None, ram=None, availability_zone=None,
+                 boot_volume_id=None, boot_cdrom=None, cpu_family=None,
+                 create_volumes=[], attach_volumes=[], nics=[]):
         """
         Server class initializer.
 
@@ -2171,8 +2187,7 @@ class Server(ProfitBricksService):
         :param      ram: The amount of memory for the server.
         :type       ram: ``str``
 
-        :param      availability_zone: The availability zone
-                                       for the server.
+        :param      availability_zone: The availability zone for the server.
         :type       availability_zone: ``str``
 
         :param      boot_volume_id: The ID of the boot volume.
@@ -2181,6 +2196,9 @@ class Server(ProfitBricksService):
         :param      boot_cdrom: Attach a CDROM.
         :type       boot_cdrom: ``str``
 
+        :param      cpu_family: Set the desired CPU type.
+        :type       cpu_family: ``str``
+
         :param      create_volumes: List of Volume dicts to create.
         :type       create_volumes: ``list``
 
@@ -2197,6 +2215,7 @@ class Server(ProfitBricksService):
         self.availability_zone = availability_zone
         self.boot_volume_id = boot_volume_id
         self.boot_cdrom = boot_cdrom
+        self.cpu_family = cpu_family
         self.create_volumes = create_volumes
         self.attach_volumes = attach_volumes
         self.nics = nics
@@ -2205,7 +2224,7 @@ class Server(ProfitBricksService):
         return ((
             '<Server: name=%s, cores=%s, ram=%s, '
             'availability_zone=%s, boot_volume_id=%s, '
-            'boot_cdrom=%s> ...>')
+            'boot_cdrom=%s, ...>')
             % (self.name, self.cores, self.ram,
                 self.availability_zone, self.boot_volume_id, self.boot_cdrom))
 
@@ -2250,6 +2269,6 @@ class Volume(ProfitBricksService):
 
     def __repr__(self):
         return ((
-            '<Volume: name=%s, size=%s, image=%s, bus=%s, disk_type=%s> ...>')
+            '<Volume: name=%s, size=%s, image=%s, bus=%s, disk_type=%s, ...>')
             % (self.name, str(self.size), self.image,
                 self.bus, self.disk_type))
